;
;------------------------------------------------------------------------------
;
; This script makes plots of biological simulations
;
; (c) Martin Vancoppenolle, UCL-ASTR, june 2007
; reviewed may 2008
; reviewed feb 2010, for biological model
; reviewed aug 2014, helsinki
; reviewed nov 2015, helsinki
;
;--------------------
;--- YROSIAE site ---
;--------------------
;
;------------------------------------------------------------------------------
;
miss_val = -9999.
i_auto = 1             ; 1=use exp_id.dat; 2=use manual mode with sensitivity runs
plot_type = 'DEFAULT'  ; 
;
;==============================================================================
; General Options
;==============================================================================
;

IF ( i_auto EQ 1 ) THEN BEGIN ; automatic mode

   nruns = 1
   control_run = 'E001' & indir = '' & outdir = '' & dt = 86400 & c_bio_model = 'BFMSI' & site = 'TOURNAI'
   
   OPENR, 11, 'exp_id.dat'
   READF, 11, control_run & READF, 11, indir & READF, 11, outdir 
   READF, 11, dt & READF, 11, c_bio_model & READF, 11, site 
   CLOSE, 11
   
   PRINT, control_run
   PRINT, indir
   PRINT, outdir
   PRINT, dt
   PRINT, c_bio_model
   PRINT, site

ENDIF

;-------------
; Manual mode
;-------------
IF ( i_auto EQ 0 ) THEN BEGIN

   indir_base = '/Users/ioulianikolskaia/Boulot/CODES/BFMLIM_2013/BFM-LIM-2506_2014/LIM/RUN/'
   outdir = '/Users/ioulianikolskaia/Boulot/SCIENCE/PLOT_SCRIPTS/LIM1D_BIO/IDL/plots/'
   dt   = 3600.        ; time step

   control_run = 'LIM_KR_ML'
   sensiti_run = [ ]
;  sensiti_run =  [ 'LIM_KR_SL', 'LIM_KR_BA' ]
   dummy = SIZE(sensiti_run) 
   nruns = dummy(1) + 1 ; sensitivity runs + 1 control run
   print, 'nruns ', nruns

   indir = STRARR(nruns)
   indir(0) = indir_base+control_run+'/'
   FOR i = 1, nruns-1 DO BEGIN
      indir(i) = indir_base+sensiti_run(i-1)+'/'
   ENDFOR

ENDIF

;
;==============================================================================
; Graphic Options
;==============================================================================
;

;--------------------------------
;--- plot_type dependent options
;--------------------------------

IF ( plot_type EQ 'DEFAULT' ) THEN BEGIN

   colors      = [  0, 200 ,   100   ,   240   ,   240   ,   120   ,   120    ]     
   linestyle   = [  0,0    ,    0    ,    1    ,     2   ,     2   ,     1    ]
   thick       = [  5, 5.  ,    5.0  ,    2.0  ,   2.0   ,   2.0   ,    2.0   ]
   stamp_out   = control_run+'_profiles'
   cs          = 1.8 ; charsize
   colorkey    = 'rd'
   ct          = 0
   !X.MARGIN   = [8,3]
   !Y.MARGIN   = [3,3]
   x_size      = 4.
   y_size      = 6.
   add_obs     = 'YES'

ENDIF

file_name = stamp_out+'.ps'

numplot_x = 5       ; number of horizontal plots
numplot_y = 2       ; number of vertical plots

device = 'PS'       ; 'PS' or 'X'

;--------------------------------
;--- define output plots
;--------------------------------
figuresize_x = numplot_x * x_size ; figure size on x direction
figuresize_y = numplot_y * y_size ; figure size on y direction
set_plot, device
IF ( device EQ 'PS' ) THEN BEGIN
   device, /COLOR, /LANDSCAPE, filename=outdir+file_name, $
           XSIZE=figuresize_x,YSIZE=figuresize_y,FONT_SIZE=9.0
   loadct, ct
ENDIF

IF ( device EQ 'X' ) THEN BEGIN
   xsize = 1200
   ysize = 800
   init_graphics_x, xsize, ysize, colorkey
ENDIF

;
;==============================================================================
; EXTRACT DATA
;==============================================================================
;
;open_fields_v6, indir(0), control_run, c_bio_model, $
;                numt, doy, ts_d, ts_m,                        $
;                h_i, h_s, z_ip, z_ib, s_i, t_i, e_i, PAR, Ra, $
;                dhib, dhisu, dhisi,                           $
;                DAFb, NO3b, PO4b, DSib, chla,                 $
;                DAFt, NO3t, PO4t, DSit,                       $
;                FDAbd, FDAbpos, FDAsi,                        $
;                FNO3, FNO3bpos, FNO3si,                       $
;                syn, lys, rem,                                $
;                lim_lig, lim_no3, lim_po4, lim_dsi, lim_tem, lim_sal
                
 open_fields_v7, indir(0), control_run, c_bio_model, $
                 numt, doy, ts_d, ts_m,                        $
                 h_i, h_s, z_ip, z_ib, s_i, t_i, e_i, PAR, Ra, $
                 dhib, dhisu, dhisi,                           $
                 DAFb, NO3b, PO4b, DSib, chla, eoCb,           $
                 Argb, Argbub, $
                 Oxyb, Oxybub, $
                 DICb, Alkb, CO2b, CO2bub,                     $
                 CO2aq, HCO3m, CO32m, pH, pCO2, Ikab,          $
                 dFeb, aFeb, eFeb,                             $
                 DAFt, NO3t, PO4t, DSit, eoCt, Argt,           $
                 DICt, Alkt, CO2t, Ikat,                       $
                 dFet, aFet, eFet,                             $
                 FDAbd, FDAbpos, FDAsi,                        $
                 FNO3, FNO3bpos, FNO3si,                       $
                 FCO2_atm, FCO2_bub,                           $
                 syn, lys, rem,                                $
                 lim_lig, lim_no3, lim_po4, lim_dsi, lim_tem, lim_sal

zsize = SIZE(DAFb)
nlay = zsize(1)   ; number of layers
nts  = zsize(2)   ; number of time steps

;
;------------------------------------------------------------------------------
; OBS ...
;------------------------------------------------------------------------------
;

; observed normalized profiles from Lannuzel et al. (2007)

N_obs = 9 ; station numbers
N_dpt = 50 ; number of depths

; DOY
doy_obs =[ 263, 279, 292, 299, 306, 312, 318, 327, 355 ]

; Ice thickness / snow depth 
hi_obs =     [ 1.472, 1.609, 1.670, 1.690, 1.708, 1.714, 1.711, 1.677, 1.693 ]
hi_obs_std = [ 0.023, 0.014, 0.009, 0.011, 0.011, 0.009, 0.016, 0.024, 0.014 ]
hs_obs = REPLICATE(0.01, 9)

h_chl     = [ 1.52, 1.60, 1.69, 1.715, 1.75, 1.72, 1.73, 1.70, 1.70  ]
h_nut     = [ 1.51, 1.60, 1.69, 1.70 , 1.72, 1.735,1.705, 1.70, 1.70 ]

; Depths
N_chl     = LONARR(N_obs)
N_chl     =  [ 15, 16, 17, 18, 18, 18, 18, 17, 17 ]

depth_chl = FLTARR(N_obs, N_dpt)

depth_chl(*,*) = miss_val
depth_chl[0,0:N_chl(0)-1] = [ 5, 15, 25, 35, 45, 55, 65, 76, 87, 97   , 107 , 117  , 127  , 137  , 147 ] / 100.
depth_chl[1,0:N_chl(1)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 95   , 105 , 115  , 125  , 135  , 145  , 155 ] / 100.
depth_chl[2,0:N_chl(2)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 94.5 , 104 , 114  , 124  , 134  , 144  , 154  , 164 ] / 100.
depth_chl[3,0:N_chl(3)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 90.75, 96.5, 106.5, 116.5, 126.5, 136.5, 146.5, 156.5, 166.5 ] / 100.
depth_chl[4,0:N_chl(4)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 92.5 , 100 , 110,   120  , 130  , 140  , 150  , 160  , 170 ] / 100.
depth_chl[5,0:N_chl(5)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 91   , 97  , 107,   117  , 127  , 137  , 147  , 157  , 167 ] / 100.
depth_chl[6,0:N_chl(6)-1] = [ 5, 15, 25, 35, 45, 55, 65, 65, 75, 85   , 95  , 106.5, 118  , 128  , 138  , 148  , 158  , 168 ] / 100.
depth_chl[7,0:N_chl(7)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 95   , 105.2, 115.2,125.2, 135.2, 145.2, 155.2, 165.2 ] / 100.
depth_chl[8,0:N_chl(8)-1] = [ 5, 15, 25, 35, 45, 55, 65, 75, 85, 95   , 105  , 115  , 125 , 135  , 145  , 155  , 165   ] / 100.

; Chlorophyll
rhoi = 917.
rhow = 1020.
chla_obs = FLTARR(N_obs, N_dpt)
chla_obs(*,*) = miss_val
chla_obs[0,0:N_chl(0)-1] = [ 0.14, 0.36, 0.12, 0.03, 0.14, 0.02, 0.01, 0.03, 0.03, 0.02, 0.19, 1.02, 1.03, 0.45, 13.28] 
chla_obs[1,0:N_chl(1)-1] = [ 0.24, 0.04, 0.06, 0.03, 0.15, 0.06, 0.13, 0.16, 0.04, 0.07, 0.26, 0.62, 0.39, 0.49, 2.85, 45.33] 
chla_obs[2,0:N_chl(2)-1] = [ 0.10, 0.08, 0.32, 0.03, 0.19, 0.06, 0.03, 0.03, 0.04, 0.06, 0.26, 0.26, 0.25, 0.27, 1.25, 2.30, 505.99 ]
chla_obs[3,0:N_chl(3)-1] = [ 0.33, 0.22, 0.97, 0.00, 0.18, 0.08, 0.06, 0.05, 0.01, 0.42, 0.20, 0.32, 0.30, 0.25, 0.18, 0.26, 1.63, 1440.73 ]
chla_obs[4,0:N_chl(4)-1] = [ 0.11, 0.12, 0.07, 0.06, 0.12, 0.06, 0.06, 0.04, 0.22, 0.13, 0.49, 0.28, 0.24, 0.36, 0.92, 1.11, 1.98, 501.79 ]
chla_obs[5,0:N_chl(5)-1] = [ 0.75, 0.20, 0.13, 0.05, 0.03, 0.07, 0.03, 0.05, 0.03, 0.06, 0.08, 0.15, 0.10, 0.05, 0.07, 0.11, 0.81, 2443.38 ]
chla_obs[6,0:N_chl(6)-1] = [ 0.18, 0.16, 0.06, 0.10, 0.08, 0.04, 0.06, 1.31, 0.03, 0.05, 0.25, 0.16, 0.06, 0.14, 0.05, 0.10, 1.39, 2342.79 ]
chla_obs[7,0:N_chl(7)-1] = [ 0.35, 0.88, 0.86, 0.53, 0.84, 0.44, 0.96, 0.44, 0.30, 0.34, 1.07, 1.69, 6.05, 0.13, 1.68, 1.18, 1203.62       ]
chla_obs[8,0:N_chl(8)-1] = [ 0.59, 0.29, 0.33, 0.28, 0.16, 0.17, 0.16, 0.11, 0.13, 0.27, 0.19, 0.22, 0.21, 0.63, 0.89, 2.35, 974.83        ]

zaddr = WHERE(chla_obs NE miss_val) 
chla_obs(zaddr) = chla_obs(zaddr)  * rhoi / rhow

; depths for nuts
N_nut = REPLICATE(6,9)
depth_nut = FLTARR(N_obs, 6)
depth_nut[0, 0:N_nut(0)-1] = [ 12.5, 37.5, 65.05, 103.5, 128.5, 146. ] / 100.
depth_nut[1, 0:N_nut(1)-1] = [   15, 45  , 75   , 105  , 135  , 155  ] / 100.
depth_nut[2, 0:N_nut(2)-1] = [   15, 47  , 79.5 , 111  , 143  , 164  ] / 100.
depth_nut[3, 0:N_nut(3)-1] = [   16, 48  , 80   , 112  , 144  , 165  ] / 100.
depth_nut[4, 0:N_nut(4)-1] = [   16, 48  , 80.5 , 113.3, 145.8, 167  ] / 100.
depth_nut[5, 0:N_nut(5)-1] = [16.35, 49.05, 71.75, 114.45, 147.15, 168.5 ] / 100.
depth_nut[6, 0:N_nut(6)-1] = [16.05, 48.15, 80.25, 112.35, 144.45, 165.5 ] / 100.
depth_nut[7, 0:N_nut(7)-1] = [   16, 48, 80, 112, 144, 165 ] / 100.
depth_nut[8, 0:N_nut(8)-1] = [ 17, 49.75, 85, 112.75, 144.25, 165 ] / 100.

; Silicates
dsi_obs = FLTARR(N_obs, 6)
dsi_obs[0,0:N_nut(0)-1] = [ 20.10, 18.03, miss_val, 12.78, 12.45, 29.98 ]
dsi_obs[1,0:N_nut(1)-1] = [ 19.81, 15.01,    14.31, 13.83,  9.68, 16.23 ]
dsi_obs[2,0:N_nut(2)-1] = [ 17.11, 14.42,    12.32,  6.07,  9.14, 28.56 ]
dsi_obs[3,0:N_nut(3)-1] = [ 17.23, 14.81,    11.90,  9.92,  4.37, 25.08 ]
dsi_obs[4,0:N_nut(4)-1] = [ 17.07, 14.81,    12.17, 11.07,  3.49, 23.19 ]
dsi_obs[5,0:N_nut(5)-1] = [ 17.89, 14.10,    12.72, 10.03,  3.10, 24.25 ]
dsi_obs[6,0:N_nut(6)-1] = [ 19.54, 14.92,    12.94, 10.36,  2.83, 33.80 ]
dsi_obs[7,0:N_nut(7)-1] = [ 20.80, 13.99,    10.85,  6.29,  1.29, 17.37 ]
dsi_obs[8,0:N_nut(8)-1] = [ 16.30, 12.89,     9.86,  2.72,  1.18, 9.83  ]

zaddr = WHERE(dsi_obs NE miss_val) 
dsi_obs(zaddr) = dsi_obs(zaddr)  * rhoi / rhow

; NOX
nox_obs = FLTARR(N_obs, 6)
nox_obs[0,0:N_nut(0)-1] = [ 10.00, 6.17, 5.80, 5.98, 3.25, 16.10 ]
nox_obs[1,0:N_nut(1)-1] = [ 7.14, 3.96, 4.59, 2.28, 0.25, 7.45 ]
nox_obs[2,0:N_nut(2)-1] = [ 8.64, 6.09, 5.04, 1.05, 1.50, 35.72 ] 
nox_obs[3,0:N_nut(3)-1] = [ 8.13, 5.72, 4.67, 0.78, 0.42, 49.64 ]
nox_obs[4,0:N_nut(4)-1] = [ 8.15, 7.07, 5.23, 0.83, 0.28, 58.91 ]
nox_obs[5,0:N_nut(5)-1] = [ 5.80, 5.02, 8.02, 1.19, 0.61, 97.09 ]
nox_obs[6,0:N_nut(6)-1] = [ 8.68, 5.90, 4.79, 0.84, 0.33, 93.78 ]
nox_obs[7,0:N_nut(7)-1] = [ 7.39, 4.61, 1.40, 0.50, 0.35, 7.94  ]
nox_obs[8,0:N_nut(8)-1] = [ 2.74, 1.29, 0.44, 0.21, 0.08, 8.54  ]

zaddr = WHERE(nox_obs NE miss_val) 
nox_obs(zaddr) = nox_obs(zaddr)  * rhoi / rhow

; PO4
po4_obs = FLTARR(N_obs, 6)
po4_obs[0,0:N_nut(0)-1] = [ 0.49, 0.38, 0.31, 0.31, 0.29, 0.72 ]
po4_obs[1,0:N_nut(1)-1] = [ 0.36, 0.24, 0.27, 0.20, 0.15, 1.80 ]
po4_obs[2,0:N_nut(2)-1] = [ 0.42, 0.31, 0.28, 0.10, 0.23, 8.47 ]
po4_obs[3,0:N_nut(3)-1] = [ 0.41, 0.28, 0.24, 0.22, 0.14, 16.54 ]
po4_obs[4,0:N_nut(4)-1] = [ 0.44, 0.33, 0.25, 0.18, 0.11, 22.05 ]
po4_obs[5,0:N_nut(5)-1] = [ 0.38, 0.33, 0.47, 0.27, 0.16, 37.34 ]
po4_obs[6,0:N_nut(6)-1] = [ 0.50, 0.34, 0.32, 0.32, 0.19, 35.61 ]
po4_obs[7,0:N_nut(7)-1] = [ 0.57, 0.38, 0.29, 0.22, 0.16, 9.79  ]
po4_obs[8,0:N_nut(8)-1] = [ 0.37, 0.21, 0.15, 0.11, 0.11, 10.96 ]

zaddr = WHERE(po4_obs NE miss_val) 
po4_obs(zaddr) = po4_obs(zaddr)  * rhoi / rhow

; physical observations

N_TS = [ 31, 33, 33, 34, 34, 35, 35, 34, 35 ]
; depth of TS cores
depth_TS = FLTARR(N_obs, N_dpt)
depth_TS(*,*) = miss_val

depth_TS[0,0:N_TS(0)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5 ] / 100.
depth_TS[1,0:N_TS(1)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 100  , 105  , 110  , 115  ,   120,   125,   130,   135,   140,   145,   150,   155, 160 ] / 100.
depth_TS[2,0:N_TS(2)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 99.5, 104.5, 109.5, 114.5, 119.5, 124.5, 129.5, 134.5, 139.9, 144.5, 149.5, 154.5, 159.5, 164.5 ] / 100.
depth_TS[3,0:N_TS(3)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5, 157.5, 162.5, 167.5 ] / 100. 
depth_TS[4,0:N_TS(4)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5, 157.5, 162.5, 167.5 ] / 100.
depth_TS[5,0:N_TS(5)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 94.5, 99.5, 104.5, 109.5, 114.5, 119.5, 124.5, 129.5, 134.5, 139.5, 144.5, 149.5, 154.5, 159.5, 164.5, 169.5 ] / 100.
depth_TS[6,0:N_TS(6)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5, 157.5, 162.5, 167.5, 172.5 ] / 100.
depth_TS[7,0:N_TS(7)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5, 157.5, 162.5, 167.5 ] / 100.
depth_TS[8,0:N_TS(8)-1] = [ 2.5, 7.5, 12.5, 17.5, 22.5, 27.5, 32.5, 37.5, 42.5, 47.5, 52.5, 57.5, 62.5, 67.5, 72.5, 77.5, 82.5, 87.5, 92.5, 97.5, 102.5, 107.5, 112.5, 117.5, 122.5, 127.5, 132.5, 137.5, 142.5, 147.5, 152.5, 157.5, 162.5, 167.5, 172.5 ] / 100.

h_TS = FLTARR(N_obs) ; We don't have thicknes of TS cores
FOR i_obs = 0, N_obs - 1 DO BEGIN
  zdh         = ( depth_TS(i_obs,N_TS(i_obs)-1) - depth_TS(i_obs,N_TS(i_obs)-2) ) / 2. 
  h_TS(i_obs) = depth_TS(i_obs,N_TS(i_obs)-1) + zdh
ENDFOR

; T-S
t_i_obs = FLTARR(N_obs, N_dpt)
t_i_obs(*,*) = miss_val

t_i_obs[0,0:N_TS(0)-1] = [ -19.8, -18.7, -18.6, -18.2, -17.5, -16.8, -16.4, -16.2, -15.3, -14.7, -14.2, -13.5, -13.1, -12.6, -11.9, -11.5, -12.4, -11.5, -10.8, -10, -9.1, -8.6, -8.1, -7, -5.7, -4.7, -4.4, -3.7, -2.9, -2.4, -2.2 ]
t_i_obs[1,0:N_TS(1)-1] = [ -12.7, -12.6, -12.8, -12.5, -12.6, -12.2, -12.3, -12.4, -11.9, -11.8, -11.6, -11.1, -10.7, -10.4, -10, -10, -9.9, -9.5, -9.4, -9.3, -8.5, -7.9, -7.3, -6.6, -6.1, -5.5, -5, -4.5, -4.2, -3.6, -2.8, -2.3, -1.9 ]
t_i_obs[2,0:N_TS(2)-1] = [ -14.6, -14.6, -14.5, -14.1, -13.5, miss_val, -12.6, -11.6, -11.8, -11.5, -11.1, -10.5, -10.2, -9.9, -9.2, -8.9, -8.7, -8.8, -9.1, -6.1, -5.6, -5.2, -4.8, -4.3, -4.2, -4.1, -3.7, -3.6, -3.1, -2.8, -2.4, -1.9, -2 ]
t_i_obs[3,0:N_TS(3)-1] = [ -12.6, -12.3, -12.2, -11.6, -11.4, -10.9, -10.1, -9.9, -9.6, -9, -8.8, -8.4, -8, -8, -7.9, -7.3, -6.9, -6.4, miss_val, miss_val, -6.2, -5.6, -5, -4.8, -4.5, -3.7, -3.7, -3.2, -2.7, -2.7, -2.6, -1.7, -2.1, -2 ]
t_i_obs[4,0:N_TS(4)-1] = [ -12.4, -12.9, -12.5, -12.2, -11.8, -11.5, -11.1, -10.5, -10.3, -9.7, -9.2, miss_val, -8.8, -8.2, -8, -7.4, -7.3, -6.7, -6.3, miss_val, -5, -4.6, -4.6, -3.9, -3.6, -3.4, -3.1, -3, -3, -2.5, -2.7, -2.2, -2, -2 ]
t_i_obs[5,0:N_TS(5)-1] = [ -10.2, -10.1, -10.2, -9.8, -9.4, -9.3, -8.9, miss_val, -8.7, -8.2, -7.8, -7.8, -7.6, -7.2, -6.6, -6.8, -6.4, -6.2, -6.2, miss_val, miss_val, -4.9, -4.6, -4.3, -4, -3.7, miss_val, -3.4, -3.2, -2.8, -2.6, -1.9, -2, -1.8, -2 ]
t_i_obs[6,0:N_TS(6)-1] = [ -7.6, -8.3, -8.2, -7.7, -7.6, miss_val, -7.1, -6.4, -7, -6.8, -6.8, -6.8, -6.9, -6.8, -6.3, -5.9, miss_val, -5.2, -5, -5, -4.8, -4.5, -4.2, -4, miss_val, -3.7, -3.4, -2.7, -2.7, -2.5, -2, -2, -1.6, -1.6, -1.9 ]
t_i_obs[7,0:N_TS(7)-1] = [ -4.5, -4.6, -4.7, -4.5, -4.6, miss_val, -4, -3.9, -3.4, -3.4, -3, -3.3, -3.2, -3, -2.7, -2.7, -2.9, -2.4, -2.4, -2.1, -2, -2.3, -1.8, -1.6, -1.7, -1.7, -1.4, -1.1, -1.4, -1.3, -1.4, -0.8, -2, -1.6 ]
t_i_obs[8,0:N_TS(8)-1] = [ -2.1, -3.3, -3.6, -3.4, -3.1, -3, -3, -2.7, -2.6, miss_val, -2.9, -2.8, -2.2, -1.7, -1.6, -2.3, -1.6, -1.7, -1.7, -1.9, -1.8, -2, -1.8, -1.4, -1.9, -1.4, -1.7, -1.8, miss_val , -1.3, -1, -1, -1.6, miss_val, miss_val ]

; S-physical core
s_i_obs = FLTARR(N_obs, N_dpt)
s_i_obs(*,*) = miss_val

s_i_obs[0,0:N_TS(0)-1] = [ 13, 11.5, 11.3, 9.7, 10.1, 9.5, 8.5, 7.6, 7.1, 6.5, 6.8, 6.2, 6.9, 6.7, 7, 7.6, 6.6, 8.2, 5.6, 4.5, 4.8, 4.8, miss_val, 5.1, 5, 4.8, 4.8, 4.7, 4.7, 5.5, 9.2 ]
s_i_obs[1,0:N_TS(1)-1] = [ 11.4, 10.1, 10.5, miss_val , 10.5, 8.8, 8, 7.1, 6.5, 6.8, 7.3, 7.2, 6.7, 6.1, 5.9, 5.9, 6, 6.2, 5.7, 5.1, 7.3, 5.9, 6, 6, 5, 4.8, 4.8, 5.7, 5.2, 3.7, 6.2, 7.1, 11 ]
s_i_obs[2,0:N_TS(2)-1] = [ 11.2, 10.5, 10.1, 9.5, 9.6, 7.5, 7.6, 7.4, 6.7, 6.5, 6.5, 6.5, 6.3, 5.8, 5.7, 5.6, 5.9, 5.3, 5, 5.4, 5.3, 4.9, 4.7, 4.2, 4.1, 4.4, 4.8, 4.4, 4.8, 5.3, 5.5, miss_val, 12.5 ]
s_i_obs[3,0:N_TS(3)-1] = [ 10.8, 10.9, 10.4, 9.4, 9.7, 8.2, 7.6, 7.1, 6.8, 6.7, 7, 7.2, 6.9, 6, 6.7, 5.9, 5.7, 5.3, 4.9, 5.4, 4.9, 5.2, 5, 4.9, 4.3, 4.6, 4.5, 4.7, 4.7, 5, 5.7, 5.4, 5.8, 13.7 ]
s_i_obs[4,0:N_TS(4)-1] = [ 10.9, 10.8, 10.1, 9, 9.4, 8.2, 8.1, 7.2, 7.3, 6.5, 6.8, 6.7, 6.7, 6.3, miss_val, 6.5, 6.6, 6.9, 6.6, miss_val, 6.1, 5.5, 5.3, 5.2, 6, 5.7, 5.7, 5.5, 5.1, 5, 5.5, 4.8, 5.5, 12.2 ]
s_i_obs[5,0:N_TS(5)-1] = [ 10.7, 10.6, 10.3, 9.6, 10.1, 8, 7.7, 7, 6.4, 6.7, 6.8, 7, 6.8, 5.4, 5.7, 5.9, 5.7, 5.4, 5, 4.8, 5.1, 5.1, 5, 4.7, 4.2, 4.1, 4.4, 4.3, 4.2, 4.9, 5.6, 5.7, 5, 5.6, 12 ]
s_i_obs[6,0:N_TS(6)-1] = [ 11.1, 10.1, 10.4, 10.8, 10.3, 9.4, 8.2, 7, 7, 6.9, 7.3, 7.3, 6.7, 6.2, 6.2, 6.2, 6.5, 6.2, 5.5, 5.1, 5.3, 5.8, 5.7, 5.7, 5.8, 5, 4.7, 4.7, 4.7, 4.7, 5.2, 5.4, 4.8, 5.8, 12.2 ]
s_i_obs[7,0:N_TS(7)-1] = [ 8.4, 9.5, 9.4, 10.1, 8.8, 7.8, 7.3, 7.3, 6.2, 6.7, 6.5, 6.2, 5.7, 5.7, 5.4, 6.1, 5.2, 4.6, 4.2, 4.3, 4.5, 4.3, 4.2, 3.6, 3.7, 3.5, 3.5, 3.3, 3.9, 4.4, 4.3, 4.7, 10.1, miss_val ]
s_i_obs[8,0:N_TS(8)-1] = [ 5.4, 6.7, 7.2, 7.6, 8.4, 7.2, 6.9, 6.5, 6.1, 6.2, 5.9, 6.1, 5.8, 4.9, 4.8, 4.7, 4.7, 4.4, 3.9, 3.4, 4.1, 3.7, 4.1, 3.8, 3.3, 3.2, 3.6, 3.1, 3.2, 3.4, 4.1, 5.2, 3.9, 4.1, 9 ]

e_i_obs = FLTARR(N_obs, N_dpt)
e_i_obs(*,*) = miss_val
zaddr = where( ( s_i_obs NE miss_val ) AND ( t_i_obs NE miss_val ) )
e_i_obs(zaddr) = - 0.054*s_i_obs(zaddr) / t_i_obs(zaddr)

; brine concentrations
e_i_nut = FLTARR(N_obs, 6)
FOR i_obs = 0, N_obs - 1 DO BEGIN
   zei   = e_i_obs(i_obs,*)
   zd    = depth_TS(i_obs,*)
   zaddr = WHERE(zei NE miss_val)
   zei   = zei(zaddr)
   zd    = zd(zaddr) / h_TS(i_obs)
   zei_itp = INTERPOL(zei, zd, depth_nut(i_obs,*)/h_nut(i_obs)); interpolate bvf on nutrient depths
   e_i_nut(i_obs,*) = zei_itp
ENDFOR

;DEVICE, /CLOSE
;SET_PLOT, 'X'
;!P.MULTI=[0,5,2]
;FOR i_obs = 0, N_obs -1 DO BEGIN
;   PLOT, [0., 100.], [-2., 0.], /NODATA, charsize = 2
;   OPLOT, e_i_obs(i_obs,0:N_TS(i_obs)-1)*100., -depth_TS(i_obs,0:N_TS(i_obs)-1)/h_TS(i_obs), psym = 1
;   OPLOT, e_i_nut(i_obs,*)*100., -depth_nut(i_obs,*)/h_nut(i_obs)
;ENDFOR
;STOP

iaddr = where ( dsi_obs NE miss_val )
dsi_br_obs = FLTARR(N_obs, 6)
dsi_br_obs(iaddr) = dsi_obs(iaddr) / e_i_nut(iaddr)

iaddr = where ( po4_obs NE miss_val )
po4_br_obs = FLTARR(N_obs, 6)
po4_br_obs(iaddr) = po4_obs(iaddr) / e_i_nut(iaddr)

iaddr = where ( nox_obs NE miss_val )
nox_br_obs = FLTARR(N_obs, 6)
nox_br_obs(iaddr) = nox_obs(iaddr) / e_i_nut(iaddr)

;*** Mean observed Profiles
;--- interpolate T, S and e on standard depths ---
N_std = 30
depth_std = FINDGEN(30) / 30.+ 1./60.

t_i_std = FLTARR(N_obs, N_std)
s_i_std = FLTARR(N_obs, N_std)
e_i_std = FLTARR(N_obs, N_std)
chla_std = FLTARR(N_obs, N_std)
FOR i_obs = 0, N_obs - 1 DO BEGIN
   zt = t_i_obs(i_obs,0:N_TS(i_obs)-1)
   zd = depth_TS(i_obs,0:N_TS(i_obs)-1)
   zaddr = WHERE( zt NE miss_val )
   zt = zt(zaddr)
   zd = zd(zaddr) / h_TS(i_obs)
   ztstd = INTERPOL( zt, zd, depth_std )
   t_i_std(i_obs,*) = ztstd(*)

   zs = s_i_obs(i_obs,0:N_TS(i_obs)-1)
   zd = depth_TS(i_obs,0:N_TS(i_obs)-1)
   zaddr = WHERE( zs NE miss_val )
   zs = zs(zaddr)
   zd = zd(zaddr) / h_TS(i_obs)
   zsstd = INTERPOL( zs, zd, depth_std )
   s_i_std(i_obs,*) = zsstd(*)

   ze = e_i_obs(i_obs,0:N_TS(i_obs)-1)
   zd = depth_TS(i_obs,0:N_TS(i_obs)-1)
   zaddr = WHERE( ze NE miss_val )
   ze = ze(zaddr)
   zd = zd(zaddr) / h_TS(i_obs)
   zestd = INTERPOL( ze, zd, depth_std )
   e_i_std(i_obs,*) = zestd(*)

   zchl    = chla_obs(i_obs,0:N_chl(i_obs)-1)
   zd      = depth_chl(i_obs,0:N_chl(i_obs)-1)
   zaddr   = WHERE( zchl NE miss_val )
   zchl    = zchl(zaddr)
   zd      = zd(zaddr) / h_chl(i_obs)
   zchlstd = INTERPOL( zchl, zd, depth_std )
   chla_std(i_obs,*) = zchlstd(*)

;  s_i_std = ...
;  e_i_std = ...
ENDFOR

;***

t_i_obs_mean = MEAN( t_i_std, dimension = 1 )
t_i_obs_std = STDDEV( t_i_std, dimension = 1 )

s_i_obs_mean = MEAN( s_i_std, dimension = 1 )
s_i_obs_std = STDDEV( s_i_std, dimension = 1 )

e_i_obs_mean = MEAN( e_i_std, dimension = 1 )
e_i_obs_std = STDDEV( e_i_std, dimension = 1 )

;depth_obs_mean = MEAN( depth_obs, DIMENSION = 1 )

chla_obs_mean  = MEAN( chla_std , DIMENSION = 1 )
chla_obs_std = STDDEV( chla_std, dimension = 1 )

dsi_obs_mean = FLTARR(N_dpt) & dsi_obs_std = FLTARR(N_dpt)
nox_obs_mean = FLTARR(N_dpt) & nox_obs_std = FLTARR(N_dpt)
po4_obs_mean = FLTARR(N_dpt) & po4_obs_std = FLTARR(N_dpt)
depth_nut_mean = FLTARR(N_dpt)
depth_nut_std = FLTARR(N_obs,6)
FOR i_obs = 0, N_obs - 1 DO BEGIN
   depth_nut_std(i_obs,*) = depth_nut(i_obs,*) / h_nut(i_obs)
ENDFOR


FOR i = 0, 5 DO BEGIN
   i_addr = WHERE( dsi_obs(*,i) NE miss_val )
   dsi_obs_mean(i) =  MEAN( dsi_obs(i_addr,i) )
   dsi_obs_std(i)  = STDDEV( dsi_obs(i_addr,i) )
   nox_obs_mean(i) =  MEAN( nox_obs(i_addr,i) )
   nox_obs_std(i)  = STDDEV( nox_obs(i_addr,i) )
   po4_obs_mean(i) =  MEAN( po4_obs(i_addr,i) )
   po4_obs_std(i)  = STDDEV( po4_obs(i_addr,i) )
   depth_nut_mean(i) = MEAN( depth_nut_std(i_addr,i) )
ENDFOR

;*** Corresponding model mean profiles
t_i_mod_mean = FLTARR(nlay)  & t_i_mod_mean(*) = 0.
t_i_mod_std  = FLTARR(nlay)  & t_i_mod_std (*) = 0.
s_i_mod_mean = FLTARR(nlay)  & s_i_mod_mean(*) = 0.
s_i_mod_std  = FLTARR(nlay)  & s_i_mod_std (*) = 0.
e_i_mod_mean = FLTARR(nlay)  & e_i_mod_mean(*) = 0.
e_i_mod_std  = FLTARR(nlay)  & e_i_mod_std (*) = 0.
chla_mod_mean = FLTARR(nlay) & chla_mod_mean(*) = 0.
chla_mod_std  = FLTARR(nlay) & chla_mod_std (*) = 0.
nox_mod_mean = FLTARR(nlay)  & nox_mod_mean(*) = 0.
nox_mod_std  = FLTARR(nlay)  & nox_mod_std (*) = 0.
po4_mod_mean = FLTARR(nlay)  & po4_mod_mean(*) = 0.
po4_mod_std  = FLTARR(nlay)  & po4_mod_std (*) = 0.
dsi_mod_mean = FLTARR(nlay)  & dsi_mod_mean(*) = 0.
dsi_mod_std  = FLTARR(nlay)  & dsi_mod_std (*) = 0.
FOR i = 0, nlay - 1 DO BEGIN

   FOR i_obs = 0, N_obs - 1 DO BEGIN
      i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
      t_i_mod_mean(i)  = t_i_mod_mean(i) + t_i(i,i_mod) / FLOAT(N_obs)
      s_i_mod_mean(i)  = s_i_mod_mean(i) + s_i(i,i_mod) / FLOAT(N_obs)
      e_i_mod_mean(i)  = e_i_mod_mean(i) + e_i(i,i_mod) / FLOAT(N_obs)
      chla_mod_mean(i) = chla_mod_mean(i) + chla(i,i_mod) / FLOAT(N_obs)
      dsi_mod_mean(i)  = dsi_mod_mean(i) + dsib(i,i_mod) / FLOAT(N_obs)
      nox_mod_mean(i)  = nox_mod_mean(i) + no3b(i,i_mod) / FLOAT(N_obs)
      po4_mod_mean(i)  = po4_mod_mean(i) + po4b(i,i_mod) / FLOAT(N_obs)
   ENDFOR

   zsum   = 0
   zsum_s = 0
   zsum_e = 0
   zsum_c = 0
   zsum_d = 0
   zsum_n = 0
   zsum_p = 0
   FOR i_obs = 0, N_obs - 1 DO BEGIN
      i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
      zsum   = zsum + ( t_i(i,i_mod) - t_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_s = zsum_s + ( s_i(i,i_mod) - s_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_e = zsum_e + ( e_i(i,i_mod) - e_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_c = zsum_c + ( chla(i,i_mod) - chla_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_d = zsum_d + ( dsib(i,i_mod) - dsi_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_n = zsum_n + ( no3b(i,i_mod) - nox_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_p = zsum_p + ( po4b(i,i_mod) - po4_mod_mean(i) ) ^2 / FLOAT(N_obs)
   ENDFOR
   t_i_mod_std(i)  = SQRT( zsum   )
   s_i_mod_std(i)  = SQRT( zsum_s )
   e_i_mod_std(i)  = SQRT( zsum_e )
   chla_mod_std(i) = SQRT( zsum_c )
   nox_mod_std(i)  = SQRT( zsum_n )
   po4_mod_std(i)  = SQRT( zsum_p )
   dsi_mod_std(i)  = SQRT( zsum_d )

ENDFOR

;-------


;
;==============================================================================
; DIAGNOSTICS
;==============================================================================
;
phi=findgen(32)*(!PI*2/32.)
phi = [ phi, phi(0) ]
usersym, cos(phi), sin(phi), /fill

;
;==============================================================================
; PLOTS
;==============================================================================
;
;
;==============================================================================
; Time series of profiles 
;==============================================================================
;
;---------
;--- T ---
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ -20, 0. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'deg C', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, -5, -0.1, ztitle

   ; add obs
   OPLOT, t_i_obs(i_obs,*), - depth_TS(i_obs,*)/h_TS(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, t_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;---------
;--- S   
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [0., 15. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'g/kg', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 7., -0.1, ztitle

   ; add obs
   OPLOT, s_i_obs(i_obs,*), - depth_TS(i_obs,*)/h_TS(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, s_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;---------
;--- e   
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [0., 50. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = '%', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 15., -0.1, ztitle

   ; add obs
   OPLOT, e_i_obs(i_obs,*)*100., - depth_TS(i_obs,*)/h_TS(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, e_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;--------------
;--- chla
;--------------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.01, 40. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mg chla / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 27., -0.1, ztitle

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, chla(*,i_mod), -zz, THICK = 3, COLOR = 150

   ; add obs
   zchlaobs = chla_obs(i_obs,0:N_chl(i_obs)-1)
   zz_obs   = depth_chl(i_obs,0:N_chl(i_obs)-1) / h_chl(i_obs)
   zchla_obs2mod = INTERPOL( zchlaobs, zz_obs,zz )
   OPLOT, zchla_obs2mod, -zz, PSYM = 1, THICK = 3, SYMSIZE = 0.8
;   print, zchla_obs2mod

ENDFOR


;------------
;--- nox  
;------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 12. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 2.2, -0.3, ztitle

   ; add obs
   OPLOT, nox_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, no3b(*,i_mod), -zz, THICK = 3, COLOR = 150

   PRINT, ' i_mod : ', i_mod
   PRINT, ' NO3b  : ', no3b(*,i_mod)

ENDFOR


;-------------
;--- po4  
;-------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 4.0 ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2
   XYOUTS, 0.37, -0.3, ztitle

   ; add obs
   OPLOT, po4_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs) , PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, po4b(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR



;--------------
;--- DSi  
;--------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 40. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol Si / m3', XTICKFORMAT='(F4.1)', XMINOR = 2, YMINOR = 2
   XYOUTS, 3.0, -0.15, ztitle

   ; add obs
   OPLOT, dsi_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, dsib(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR

;
;==============================================================================
; Time series of profiles, brine concentrations
;==============================================================================
;

;--- nox_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0., 300. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 20.0, -0.15, ztitle

   ; add obs
   OPLOT, nox_br_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, no3b(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 1.6, 1.6 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;--- po4_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.0, 15. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, $
         SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I3)', XMINOR = 2, XTICKS = 3 , YMINOR = 2
   XYOUTS, 10., -0.15, ztitle

   ; add obs
   OPLOT, po4_br_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, po4b(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 0.24, 0.24 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;--- dsi_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0., 750. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol Si / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 20.0, -0.15, ztitle

   ; add obs
   OPLOT, dsi_br_obs(i_obs,*), - depth_nut(i_obs,*)/h_nut(i_obs), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, dsib(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 3.90, 3.90 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;
;==============================================================================
; Mean profiles
;==============================================================================
;
!P.MULTI=[0,numplot_x, numplot_y]

;--- T ---

; prepare plot
LOADCT, 0
ztitle = "Mean T"
PLOT, [ -20., 0. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'deg C', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, t_i_obs_mean, - depth_std, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ t_i_obs_mean(i) - t_i_obs_std(i), t_i_obs_mean(i) + t_i_obs_std(i) ], $
          [ -depth_std(i), -depth_std(i) ]
ENDFOR
LOADCT, 3
OPLOT, t_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, t_i_mod_mean+t_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, t_i_mod_mean-t_i_mod_std, -zz, THICK = 1, COLOR = 150

;--- S ---

; prepare plot
LOADCT, 0
ztitle = "Mean S"
PLOT, [0., 12. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'g/kg', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, s_i_obs_mean, - depth_std, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ s_i_obs_mean(i) - s_i_obs_std(i), s_i_obs_mean(i) + s_i_obs_std(i) ], $
          [ -depth_std(i), -depth_std(i) ]
ENDFOR

; add model
LOADCT, 3
OPLOT, s_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, s_i_mod_mean+s_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, s_i_mod_mean-s_i_mod_std, -zz, THICK = 1, COLOR = 150

;--- e ---

; prepare plot
LOADCT, 0
ztitle = "Mean e"
   PLOT, [0., 50. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = '%', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, e_i_obs_mean*100., - depth_std, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ e_i_obs_mean(i) - e_i_obs_std(i), e_i_obs_mean(i) + e_i_obs_std(i) ] * 100., $
          [ -depth_std(i), -depth_std(i) ]
ENDFOR

; add model
LOADCT, 3
OPLOT, e_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, e_i_mod_mean+e_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, e_i_mod_mean-e_i_mod_std, -zz, THICK = 1, COLOR = 150



;--- chl-a ---

; prepare plot
LOADCT, 0
ztitle = "Mean chla"
PLOT, [ 0.01, 40. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mg chla / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, chla_obs_mean, - depth_std, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ chla_obs_mean(i) - chla_obs_std(i), chla_obs_mean(i) + chla_obs_std(i) ], $
          [ -depth_std(i), -depth_std(i) ]
ENDFOR
; plot seawater value
LOADCT, 1
OPLOT, [ 0.08 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, chla_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, chla_mod_mean+chla_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, chla_mod_mean-chla_mod_std, -zz, THICK = 1, COLOR = 150

;--- NOX ---

; prepare plot
LOADCT, 0
ztitle = "Mean NOX"
PLOT, [ 0.00, 35. ], [ -1.0, 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, nox_obs_mean, - depth_nut_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, 5 DO BEGIN
   OPLOT, [ nox_obs_mean(i) - nox_obs_std(i), nox_obs_mean(i) + nox_obs_std(i) ], $
          [ -depth_nut_mean(i), -depth_nut_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 31.16 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, nox_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, nox_mod_mean+nox_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, nox_mod_mean-nox_mod_std, -zz, THICK = 1, COLOR = 150

;--- PO4 ---

; prepare plot
LOADCT, 0
ztitle = "Mean PO4"
PLOT, [ 0.00, 4.0 ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, po4_obs_mean, - depth_nut_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ po4_obs_mean(i) - po4_obs_std(i), po4_obs_mean(i) + po4_obs_std(i) ], $
          [ -depth_nut_mean(i), -depth_nut_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 2.05 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, po4_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, po4_mod_mean+po4_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, po4_mod_mean-po4_mod_std, -zz, THICK = 1, COLOR = 150

;--- DSi ---

; prepare plot
LOADCT, 0
ztitle = "Mean DSi"
PLOT, [ 0.00, 90. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, dsi_obs_mean, - depth_nut_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_std - 1 DO BEGIN
   OPLOT, [ dsi_obs_mean(i) - dsi_obs_std(i), dsi_obs_mean(i) + dsi_obs_std(i) ], $
          [ -depth_nut_mean(i), -depth_nut_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 84.35 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, dsi_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, dsi_mod_mean+dsi_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, dsi_mod_mean-dsi_mod_std, -zz, THICK = 1, COLOR = 150

;
;==============================================================================
; End of the script
;==============================================================================
;
IF ( device EQ 'PS' ) THEN BEGIN
   DEVICE, /CLOSE
   SET_PLOT, "X"
   !P.MULTI=[0,2,2]
ENDIF

END

